@@ -1,10 +1,11 @@
 import sys
 import pyfsdb.tools.pdbdatetoepoch
 
+
 def main():
     sys.stderr.write("dbdatetoepoch is obsolete; please use pdbdatetoepoch instead\n")
     pyfsdb.tools.pdbdatetoepoch.main()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
